@@ -44,6 +44,7 @@ set( 'SQL_INTERVAL_SELECT_BY_IID', q/
 set( 'SQL_INTERVAL_SELECT_BY_EID_AND_TSRANGE', q/
       SELECT i.iid, i.eid, i.aid, a.code, i.intvl, i.long_desc, i.remark
       FROM intervals i, activities a WHERE i.eid = ? AND i.intvl <@ ? AND i.aid = a.aid
+      ORDER BY i.intvl
       LIMIT ?
       / );
 
@@ -54,12 +55,14 @@ set( 'SQL_INTERVAL_SELECT_BY_EID_AND_TSRANGE_PARTIAL_INTERVALS', q/
       EXCEPT
       SELECT i.iid, i.eid, i.aid, a.code, i.intvl, i.long_desc, i.remark
       FROM intervals i, activities a WHERE i.eid = ? AND i.intvl <@ ? AND i.aid = a.aid
+      ORDER BY 5
       / );
 
 #
 set( 'SQL_INTERVAL_SELECT_BY_EID_AND_TSRANGE_INCLUSIVE', q/
       SELECT i.iid, i.eid, i.aid, a.code, i.intvl, i.long_desc, i.remark
       FROM intervals i, activities a WHERE i.eid = ? AND i.intvl && ? AND i.aid = a.aid
+      ORDER BY i.intvl
       LIMIT ?
       / );
 
